---
title: "LCVPrestaConnector - Documentation technique"
header-left: "LCVPrestaConnector - Documentation technique"
footer-center: "[page]"
pdf-engine: wkhtmltopdf
...

# Manuel technique

La section suivante détaille les choix et le fonctionnement techniques du module `LcvPrestaConnector`, ainsi que les données prisent en compte.

Vous pouvez télécharger le module à l'URL suivante : https://ftp.vega-net.net/dists/lcvprestaconnector/stable/prestashop8/lcvprestaconnector.zip.

Vous pouvez remplacer `/prestashop8/` dans l'URL par la version majeure du système Prestashop que vous utilisez (i.e. prestashop9 pour la version 9 de Prestashop).


## Pré-requis techniques

Le module est conçu et développé pour fonctionner avec les versions minimales suivantes des bibliothèques :

- **Prestashop 8.1.7**
- PHP 8.1
- MariaDB 13

*Aucun support ni correctif ne sera fourni pour supporter des versions moins élevées de ces dépendances.*

## Modes de fonctionnement

Le module possède deux modes :

1. le **mode basique** : dans le mode basique, le module synchronise uniquement les stocks, les prix et les promotions en se basant sur la référence fournisseur LCV. 
2. le **mode complet** : dans le mode complet, en plus d'effectuer toutes les actions du mode basique, le module crée et tient les fiches produits à jour pour tous les produits déclarés comme publiés sur le site Internet. Quand une donnée existe sur le backoffice LCV, elle est reportée dans Prestashop à la création ; par la suite, si lors d'une synchronisation la donnée existe déjà sous Prestashop, celle-ci est écrasée par la valeur de LCV en fonction de votre configuration. Les données vitales (♜) sont toujours écrasées dans Prestashop ;

*Note : les données marquées d'une tour (♜) sont des données vitales de classification. Ces données sont toujours écrasées par le module si elles existent sous LCV.*



## Fonctionnement général

Le module répond au fonctionnement suivant :

- à intervalle régulier, il est nécessaire d'appeler la tâche cron présente à l'adresse https://votresite.com/module/lcvprestaconnector/cron?guard=XXXX ; consultez la page de configuration du module pour connaître la valeur exacte du jeton d'accès (*guard*) ;
- c'est cette tâche qui va initier la communication entre le site Prestashop et votre backoffice et réaliser les opérations d'importation et d'exportation des données en se connectant aux API de votre backoffice ;
- il est nécessaire d'appeler cette tâche régulièrement ;
- la tâche ne resynchronise pas la totalité de vos données systématiquement mais, dans le domaine du possible et sauf ordre contraire ponctuel, cherche à travailler en incrémentiel - *ie.* de ne s'occuper que des données qui ont changées ;

Le module est conçu pour avoir un impact minimal sur le *front* du site. 



## Fonctionnalités avancées

### Mise à jour automatique

Le module est doté d'un système de mise à jour automatique. Au moins une fois par jour, lors de l'appel d'une tâche de synchronisation, il se connecte à nos serveurs pour vérifier si une nouvelle version est disponible. Dans un tel cas, il télécharge l'archive ZIP contenant la mise à jour et la déploie dans le répertoire `/updates/lastest`. 

Il informe ensuite Prestashop de la disponibilité de la mise à jour. Les utilisateurs ayant le droit peuvent  alors la déployer comme n'importe quel module depuis le gestionnaire de modules de Prestashop.

La mise à jour de la base de données est effectuée automatiquement lors du prochain appel au module.

Nous vous conseillons de mettre à jour le module régulièrement pour bénéficier d'une meilleure prise en charge de votre backoffice, de nos correctifs de sécurité, de fonctionnement, ainsi que des nouvelles fonctionnalités.



### Sélecteur de produits connexes

Le module permet, selon sa configuration, de scinder les produits LCV en plusieurs produits Prestashop, par exemple pour mieux gérer la couleur. Le module garde la trace du lien de parenté des produits créés de la sorte et incorpore un *hook* qui permet de générer un sélecteur pour naviguer entre ces produits.

Pour utiliser ce sélecteur, appeler le *hook* `{hook h='displayMultiProductSelector' product=$product}` dans la *template* (tpl) de la page produit à l'endroit où vous souhaitez générer le code HTML.

Vous pouvez maquiller le rendu du sélecteur par CSS et en modifier le rendu, comme par exemple cacher la variante affichée actuellement, modifier les couleurs, etc...

*Notez que le sélecteur ne s'affiche pas (rendu vide) lorsqu'il n'y a qu'une seule variante activée et affichable (avec du stock) pour le produit actuellement visualisé.*



## Données synchronisées

### Produits

Fonctionnement général :

- sur LCV, certaines déclinaisons peuvent être discriminantes (par exemple, la couleur ou la matière), d'autres peuvent être des tailles (longueurs de jambe, bonnets, ...) ;
- chaque couple `{produit - déclinaisons discriminantes}` de LCV qui est marqué pour être sur Internet provoque la création et l'entretien d'un produit sous Prestashop ;
- dans ce produit Prestashop, chaque couple `{article - déclinaisons de taille}` de LCV provoque la création d'une déclinaison unique lorsque celle-ci n'existe pas déjà ;
- **la clé de synchronisation (la donnée utilisée pour reconnaître l'entité) est le code-barre LCV de l'article, injecté dans la référence fournisseur du produit, pour le fournisseur nommé `LCV`.** 

#### Données synchronisées sur le produit

*Quand la donnée n'est pas présente dans la colonne Prestashop, alors c'est que la donnée n'est pas synchronisée.*

| Donnée Prestashop                          | Notes                                                        |
| ------------------------------------------ | ------------------------------------------------------------ |
| Référence produit ♜                        | La référence utilisée est la référence produit sous LCV concaténée aux libellés des déclinaisons discriminantes, séparées par le caractère `/`. |
| Référence fournisseur du fournisseur LCV ♜ | La référence produit LCV, agrégée des références de déclinaisons discriminante est utilisée ici. |
| Nom                                        | —                                                            |
| Marque                                     | —                                                            |
| Taux de taxes (TVA)                        | —                                                            |
| Écotaxe                                    | —                                                            |
| Description                                | —                                                            |
| Description Méta                           | —                                                            |
| Largeur, longueur, hauteur/profondeur, poids | Extrait automatiquement des les champs paramétrables LCV du même nom  |
| Prix de vente de base ♜                   | Le prix de vente de base est le prix le plus bas, toutes déclinaisons et tailles confondues. |
| Caractéristiques                           | Les caractéristiques sont définies par mappages de champs dynamiques dans LCV ; voir la configuration pour plus de détails. |
| Catégories                                 | Les catégories sont définies par mappage des `Rayons` et des `Familles` LCV. |
| Photos                                     | —                                                            |

#### Données synchronisée sur la déclinaison

*Quand la donnée est barrée dans la colonne Prestashop, alors c'est que la donnée n'est pas synchronisée avec cette version du module.*

| Donnée Prestashop                          | Notes                                                        |
| ------------------------------------------ | ------------------------------------------------------------ |
| Référence de la déclinaison ♜              | C'est le code-barre LCV qui est utilisé ici.                 |
| Référence fournisseur du fournisseur LCV ♜ | Le code barre LCV est utilisé ici comme clé de synchronisation. |
| Attributs constituants la déclinaison ♜    | Les déclinaisons non-discriminantes et les tailles LCV sont utilisées pour créer les déclinaisons Prestashop. |
| Prix de vente ♜                            | Prix de vente en boutique.                                   |
| Code barre EAN13                           | Le premier code barre fournisseur sous LCV (EAN_1).          |
| ~~Emplacement du stock~~                   | Non synchronisé sur cette version.                           |
| Association de photo                       | Le module rétablit les bonnes photos avec les bonnes déclinaisons automatiquement. |

### Marques

Les marques ne sont pas créées automatiquement par le module, mais mappée. 

Chaque fois que le module rencontre une nouvelle marque, il crée une ligne de mappage qu'il faudra configurer dans les options du module ou paramétrer un catch-all pour affecter la marque.

Une resynchronisation complète est nécessaire après modification du mappage.

### Caractéristiques, Tailles & Attributs

Les caractéristiques, tailles et autres attributs ne sont pas synchronisés au même titre que le reste des données. 

Lorsque le module synchronise un produit référençant l'une de ses données et que la caractéristique ou le groupe d'attributs a été mappé, il regarde si une valeur équivalente existe. Si c'est le cas, il l'utilise ; autrement, il crée la valeur de caractéristique ou l'attribut et l'utilise. 

Pour ces données, seule la caractéristique ou le groupe d'attributs est mappé, pas les valeurs qui le/la composent.

### Catégories

Les catégories sont systématiquement mappées. A chaque nouvelle catégorie de produit sur le backoffice LCV, une ligne de mapping est créée par le module. Quand celle-ci est renseignée, tous les produits appartenant à cette catégorie LCV sont automatiquement assignés aux catégories Prestashop renseignées pour cette ligne. 

Le module essaye au mieux possible de ne pas toucher aux associations que vous auriez fait manuellement, mais il est possible qu'il modifie les catégories d'un produit pensant défaire une association caduque si vous avez associé manuellement votre produit à l'une des catégories gérées par le mappage.

Aussi, une resynchronisation complète est nécessaire après modification du mappage.

### Stock (♜)

Le module télécharge les stocks ventilés par point de vente et dépôts dans la table `ps_pc_lcv_stocks` puis les agrège dans la table de Prestashop `ps_stock_available` prévu à cet effet en passant par les objets internes pour déclencher tous les *hooks* du système afin que les modules se basant sur le changement des stocks puissent fonctionner correctement.

Vous pouvez vous appuyer sur la table `ps_pc_lcv_stocks`pour calculer et afficher une disponibilité d'article au magasin dans votre propre module si vous le désirez.

Il est à noter que sur option, est déduit de ces stocks agrégés une quantité minimale de stock de sécurité pour chaque taille.

### Promotions

Les promotions sont synchronisées sous la forme de prix spécifique sous Prestashop. Le module fait au mieux pour en créer le moins possible et de les regrouper lorsque la promotion concerne toutes les déclinaisons d'un produit. 

De même le module ne crée que des promotions en % et ne touche pas aux promotions manuelles que le marchand pourrait créer lui-même. Pour cela, le module gère une copie de ses promotions dans la table `ps_pc_lcv_promotion` et `ps_pc_lcv_promotion_detail`.

Le module retire de lui-même les promotions caduques.

Il est possible de mapper une promotion avec une catégorie de sorte qu'un produit faisant partie de cette promotion soit automatiquement associé à cette catégorie Prestashop le temps de la promotion ; option particulièrement utile pour nommer ou présenter cette opération commerciale sur le site.

### Clients

Les clients sont exportés vers le backoffice LCV lors de la tâche automatisée de synchronisation si la configuration le permet.

- Les clients ne sont pas importés depuis LCV, seulement exportés.
- Les modifications clients sont exportées vers LCV s'il a passé au moins une commande sur le site Prestashop ou s'il fait parti du groupe de clients "Clients LCV" et si ce n'est pas un compte invité et qu'il ne s'agit pas d'un compte écran créé automatiquement par une plateforme de e-commerce *(compte écran ...@amazon.marketplace.com)* ; le module tente de les reconnaître dans la mesure du possible.

| Donnée                      | Notes                                                        |
| --------------------------- | ------------------------------------------------------------ |
| Email                       |                                                              |
| Nom                         | Nom en majuscule                                             |
| Prénom                      | Prénom capitalisé                                            |
| Civilité                    | Importé/Exporté seulement si un titre de civilité identique est présent sous Prestashop, sinon ignoré. |
| Inscription à la newsletter |                                                              |
| Mot de passe                | Non synchronisé mais créé aléatoirement lors de la création du client sous Prestashop. |
| Date de naissance           | Au format YYYY-MM-DD                                         |

*Notes :* pour des raisons de sécurité des données et la compréhension du système, les clients ne sont exportés depuis Prestashop vers le backoffice que lorsqu'ils subissent une modification sur Prestashop. Ils ne sont pas rexportés en totalité lorsque une resynchronisation totale est demandée. *Pour obtenir le renvoi de tous les clients vers LCV, prévoyez un UPDATE du champ date_upd de la table `ps_customer`.*


### Commandes

Les commandes sont exportées vers le backoffice LCV lors de la tâche automatisée de synchronisation dès qu'elles correspondent à toutes les conditions suivantes :
- le statut actuel de la commande est considéré comme payée (une facture a été émise par Prestashop) ; 
- le statut actuel de la commande n'est pas "Erreur d'exportation vers LCV" ;
- la date de création de la commande est inférieure à 90 jours ;
- la dernière mise à jour de la commande remonte à moins de 30 jours ;
- tous les règlements utilisées pour la payer sont mappés dans la configuration ;
- le montant initial de la commande est strictement égal au montant encaissé avec les paiements ;
- la commande contient au moins un article à livrer ;

Lorsqu'un paiement n'est pas mappé ou qu'un nouveau type de paiement est rencontrer lors d'une exportation, ce dernier est automatiquement ajouté aux modes de règlements devant être mappés.

A l'issu de l'exportation, la commande se voit affublée d'un des deux statuts suivants, créés automatiquement par le module lorsqu'ils n'existent pas :

- Exportée vers LCV : la commande a bien été exportée sous LCV, sans erreur ;
- Erreur d'exportation vers LCV : la commande n'a pas été exportée sous LCV. L'erreur est présente dans le journal de Prestashop et dans l'audit de synchronisation ; 

*Le système est prévu pour retenter l'envoi de la commande dès qu'il détecte une modification sur la commande et qu'elle obéit aux conditions préalablement indiquées ci-dessus.*

Voici les données exhaustives prises en charge par cet export manuel ou automatique :

| Donnée                   | Notes                                                        |
| ------------------------ | ------------------------------------------------------------ |
| Référence de la commande |                                                              |
| Date de la vente         | C'est la date du paiement ici qui est pris en compte et non la date de la commande, essentiellement pour des questions fiscales. |
| Type de la vente         |                                                              |
| Magasin                  |                                                              |
| Produits                 | Pour chaque produit, est exporté :<br />- le code barre LCV ; à défaut le Gencode s'il est présent<br />- la quantité<br />- le prix de vente TTC consenti<br />- le montant TTC de la remise, si existante. (les remises sont typées en Promotion)<br />- le taux de TVA pratiqué sur le site<br /> |
| Les règlements           |                                                              |
| Remise panier            |                                                              |
| Client                   | Si le client n'est pas un compte invité et si l'option d'exportation des clients vers LCV a été activée, alors le client est liée à la vente. |

Les commandes sont toujours exportées dans la devise par défaut du site Internet : si la commande est réalisée dans une autre devise, alors tous les montants sont convertis dans la monnaie principale du site.

#### Modification, annulation, retours & remboursement

Le module ne traite les modifications, annulations, retours & remboursements qu'à la condition que l'option éponyme ait été activée dans sa configuration. Autrement, seule la primo version de la commande est exportée vers LCV.

*Note : en raison d'une très grande liberté d'édition des commandes sous Prestashop, il est souvent possible d'arriver à un résultat non importable dans LCV, notamment en cas de remboursement partiel ou de modifications successives de la commande. Dans ce cas, une erreur d'exportation se produit et il faudra corriger la situation manuellement directement sur le backoffice.*

Quand le système détecte une modification d'une commande payée, une annulation, un retour ou un remboursement sur une commande, il suit toujours la procédure suivante :

- si la commande est exportable et ne l'a jamais été, le module exporte d'abord une version originale de la commande en l'état ;
- si la commande a été dans un état exportable, n'a pas été exportée à l'époque et ne se trouve plus dans un état exportable, alors le module n'exportera pas cette commande ;
- ensuite, s'il y a déjà eu une ou plusieurs modifications pour cette commande qui ont été exportées, le module annule ces modifications en les passant sur le backoffice en sens inverse ;
- puis, si la commande se trouve dans un état exportable ou si la commande n'est plus dans un état exportable, mais l'a été un jour et a déjà été synchronisée avec le backoffice, alors, le module exportera une vente qui reflète la différence entre la commande d'origine et la commande à l'heure de l'exportation ;


## Erreurs fréquentes

Sans objet.
